#' @keywords internal
#' @importFrom methods getClassDef getSlots is new representation setClass
#'   setMethod signature
#' @importFrom utils modifyList
#' @import copula
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
#' @useDynLib VC2copula, .registration = TRUE
#' @import methods
#' @import copula
## usethis namespace: end
"_PACKAGE"
